@@ -1,13 +1,13 @@
 var group__spa__pod =
 [
     [ "builder.h", "builder_8h.html", null ],
-    [ "command.h", "pod_2command_8h.html", null ],
+    [ "pod/command.h", "pod_2command_8h.html", null ],
     [ "compare.h", "compare_8h.html", null ],
-    [ "event.h", "pod_2event_8h.html", null ],
-    [ "filter.h", "spa_2include_2spa_2pod_2filter_8h.html", null ],
+    [ "pod/event.h", "pod_2event_8h.html", null ],
+    [ "spa/include/spa/pod/filter.h", "spa_2include_2spa_2pod_2filter_8h.html", null ],
     [ "iter.h", "iter_8h.html", null ],
     [ "parser.h", "parser_8h.html", null ],
-    [ "pod.h", "pod_2pod_8h.html", null ],
+    [ "pod/pod.h", "pod_2pod_8h.html", null ],
     [ "vararg.h", "vararg_8h.html", null ],
     [ "spa_pod_builder_state", "structspa__pod__builder__state.html", [
       [ "offset", "structspa__pod__builder__state.html#ac64c9a0aad0f5630c44c86e97561ffae", null ],
@@ -355,7 +355,7 @@ var group__spa__pod =
     [ "spa_pod_builder_push_object", "group__spa__pod.html#gab99db8b4a691fb02158e43a6eac39d96", null ],
     [ "spa_pod_builder_prop", "group__spa__pod.html#ga08615272e6e8633377ecdd5d22aec287", null ],
     [ "spa_pod_builder_push_sequence", "group__spa__pod.html#ga5f0935793f667923844cab08ea6f8637", null ],
-    [ "spa_pod_builder_control", "group__spa__pod.html#ga82e4fb3f51ce8215e63bfb0eefc812e9", null ],
+    [ "spa_pod_builder_control", "group__spa__pod.html#ga7e2695ed7013bdf6791e692e3c726452", null ],
     [ "spa_choice_from_id", "group__spa__pod.html#ga7b7954e6302929958069d1eed005ab9b", null ],
     [ "spa_pod_builder_addv", "group__spa__pod.html#gaef57db1bd9e4683c0e96dd2d8e4dfc0c", null ],
     [ "spa_pod_builder_add", "group__spa__pod.html#ga4ed91d7bcbccedf0f26dbd3f563f900b", null ],
